@@ -1,23 +1,6 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2011, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.jboss.as.connector.logging;
@@ -44,6 +27,7 @@ import org.jboss.logging.annotations.Cause;
 import org.jboss.logging.annotations.LogMessage;
 import org.jboss.logging.annotations.Message;
 import org.jboss.logging.annotations.MessageLogger;
+import org.jboss.modules.ModuleLoadException;
 import org.jboss.msc.service.StartException;
 import org.jboss.vfs.VirtualFile;
 
@@ -453,7 +437,7 @@ public interface ConnectorLogger extends BasicLogger {
      * @return an {@link IllegalStateException} for the error.
      */
     @Message(id = 47, value = "Connection is not valid")
-    IllegalStateException invalidConnection();
+    IllegalStateException invalidConnection(@Cause Exception e);
 
 //    /**
 //     * A message indicating the parameter name is invalid.
@@ -647,22 +631,22 @@ public interface ConnectorLogger extends BasicLogger {
     @Message(id = 69, value = "At least one xa-datasource-property is required for an xa-datasource")
     OperationFailedException xaDataSourcePropertiesNotPresent();
 
-    /**
-     * A message indicating that jndi-name is missing and it's a required attribute
-     *
-     * @return the message.
-     */
-    @Message(id = 70, value = "Jndi name is required")
-    OperationFailedException jndiNameRequired();
+//    /**
+//     * A message indicating that jndi-name is missing and it's a required attribute
+//     *
+//     * @return the message.
+//     */
+//    @Message(id = 70, value = "Jndi name is required")
+//    OperationFailedException jndiNameRequired();
 
 
-    /**
-     * A message indicating that jndi-name has an invalid format
-     *
-     * @return the message.
-     */
-    @Message(id = 71, value = "Jndi name have to start with java:/ or java:jboss/")
-    OperationFailedException jndiNameInvalidFormat();
+//    /**
+//     * A message indicating that jndi-name has an invalid format
+//     *
+//     * @return the message.
+//     */
+//    @Message(id = 71, value = "Jndi name have to start with java:/ or java:jboss/")
+//    OperationFailedException jndiNameInvalidFormat();
 
     /**
      * Creates an exception indicating the deployment failed.
@@ -680,8 +664,8 @@ public interface ConnectorLogger extends BasicLogger {
      * @param moduleName the module name.
      * @return the message.
      */
-    @Message(id = 73, value = "Failed to load module for RA [%s]")
-    String failedToLoadModuleRA(String moduleName);
+    @Message(id = 73, value = "Failed to load module for RA [%s] Cause: %s")
+    String failedToLoadModuleRA(String moduleName, String cause);
 
     /**
      * Creates an exception indicating a method is undefined.
@@ -950,7 +934,36 @@ public interface ConnectorLogger extends BasicLogger {
     @Message(id = 121, value = "Unable to start the data source '%s' because there is more than one(%s) connection factory defined.")
     StartException cannotStartDSTooManyConnectionFactories(String dataSourceJNDIName, int factoriesCount);
 
-
     @Message(id = 122, value = "Thread pool name %s(type: %s) must match the workmanager name %s.")
     OperationFailedException threadPoolNameMustMatchWorkManagerName(String threadPoolName, String threadPoolType, String workManagerName);
+
+    @Message(id = 123, value = "Connection definition %s from resource adapter %s is configured to require the legacy security subsystem, which is not present")
+    OperationFailedException legacySecurityNotAvailable(String connectionDef, String ra);
+
+    @Message(id = 124, value = "Datasource %s is configured to require the legacy security subsystem, which is not present")
+    OperationFailedException legacySecurityNotAvailable(String datasourceName);
+
+    @Message(id = 125, value = "Datasource %s is configured to require the legacy security subsystem, which is not present")
+    DeploymentUnitProcessingException legacySecurityNotAvailableForDsXml(String datasourceName);
+
+    @Message(id = 126, value = "Connection definition for %s is configured to require the legacy security subsystem, which is not present")
+    DeploymentUnitProcessingException legacySecurityNotAvailableForRa(String deploymentName);
+
+    @Message(id = 127, value = "Connection factory  %s is configured to require the legacy security subsystem, which is not present")
+    IllegalStateException legacySecurityNotAvailableForConnectionFactory(String jndiName);
+
+    @Message(id = 128, value = "Legacy security is not available")
+    IllegalStateException legacySecurityNotAvailable();
+
+    @Message(id = 129, value = "Wrong module name %s")
+    OperationFailedException wrongModuleName(@Cause ModuleLoadException exception, String moduleName);
+
+    @Message(id = 130, value = "Report directory %s does not exist")
+    OperationFailedException reportDirectoryDoesNotExist(String reportDirectory);
+
+    @Message(id = 131, value = "Legacy security attribute %s is no longer supported. Please use Elytron configuration instead")
+    OperationFailedException legacySecurityAttributeNotSupported(String attribute);
+
+    @Message(id = 132, value = "Legacy security is no longer supported. Please use Elytron configuration instead")
+    String legacySecurityNotSupported();
 }
