@@ -1,23 +1,6 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2013, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.wildfly.extension.messaging.activemq.deployment;
@@ -40,14 +23,13 @@ import static org.wildfly.extension.messaging.activemq.logging.MessagingLogger.R
 
 import java.util.Map;
 
-import javax.jms.Destination;
-import javax.jms.Queue;
-import javax.jms.Topic;
+import jakarta.jms.Destination;
+import jakarta.jms.Queue;
+import jakarta.jms.Topic;
 
 import org.jboss.as.connector.deployers.ra.AdministeredObjectDefinitionInjectionSource;
 import org.jboss.as.controller.PathAddress;
 import org.jboss.as.controller.PathElement;
-import org.jboss.as.ee.component.InjectionSource;
 import org.jboss.as.ee.resource.definition.ResourceDefinitionInjectionSource;
 import org.jboss.as.naming.ContextListAndJndiViewManagedReferenceFactory;
 import org.jboss.as.naming.ManagedReferenceFactory;
@@ -67,6 +49,7 @@ import org.jboss.msc.service.ServiceName;
 import org.jboss.msc.service.ServiceTarget;
 import org.wildfly.extension.messaging.activemq.MessagingExtension;
 import org.wildfly.extension.messaging.activemq.MessagingServices;
+import org.wildfly.extension.messaging.activemq.jms.ConnectionFactoryAttributes.External;
 import org.wildfly.extension.messaging.activemq.jms.DestinationConfiguration;
 import org.wildfly.extension.messaging.activemq.jms.ExternalJMSQueueService;
 import org.wildfly.extension.messaging.activemq.jms.ExternalJMSTopicService;
@@ -116,23 +99,16 @@ public class JMSDestinationDefinitionInjectionSource extends ResourceDefinitionI
         this.destinationName = destinationName;
     }
 
-    private String uniqueName(InjectionSource.ResolutionContext context) {
+    protected String uniqueName(ResolutionContext context) {
         if (destinationName != null && !destinationName.isEmpty()) {
             return destinationName;
         }
 
-        StringBuilder uniqueName = new StringBuilder();
-        uniqueName.append(context.getApplicationName()).append("_");
-        uniqueName.append(context.getModuleName()).append("_");
-        if (context.getComponentName() != null) {
-            uniqueName.append(context.getComponentName()).append("_");
-        }
-        uniqueName.append(jndiName);
-        return uniqueName.toString();
+        return super.uniqueName(context);
     }
 
     @Override
-    public void getResourceValue(final InjectionSource.ResolutionContext context, final ServiceBuilder<?> serviceBuilder, final DeploymentPhaseContext phaseContext, final Injector<ManagedReferenceFactory> injector) throws DeploymentUnitProcessingException {
+    public void getResourceValue(final ResolutionContext context, final ServiceBuilder<?> serviceBuilder, final DeploymentPhaseContext phaseContext, final Injector<ManagedReferenceFactory> injector) throws DeploymentUnitProcessingException {
         if(resourceAdapter == null || resourceAdapter.isEmpty()) {
             resourceAdapter = getDefaulResourceAdapter(phaseContext.getDeploymentUnit());
         }
@@ -158,7 +134,7 @@ public class JMSDestinationDefinitionInjectionSource extends ResourceDefinitionI
         try {
             ServiceName serviceName;
             if(external) {
-                serviceName = MessagingServices.getActiveMQServiceName("");
+                serviceName = MessagingServices.getActiveMQServiceName();
             } else {
                 serviceName = MessagingServices.getActiveMQServiceName(getActiveMQServerName(properties));
             }
@@ -200,6 +176,8 @@ public class JMSDestinationDefinitionInjectionSource extends ResourceDefinitionI
         destination.get(ENTRIES).add(jndiName);
         Service<Queue> queueService;
         if(external) {
+            // check @JMSDestinationDefinitions boolean property named enable-amq1-prefix for runtime queue
+            final boolean enabledAMQ1Prefix = properties.containsKey(External.ENABLE_AMQ1_PREFIX.getName()) ? Boolean.valueOf(properties.get(External.ENABLE_AMQ1_PREFIX.getName())) : External.ENABLE_AMQ1_PREFIX.getDefaultValue().asBoolean();
             ServiceName pcfName= JMSServices.getPooledConnectionFactoryBaseServiceName(serverServiceName).append(resourceAdapter);
             final ServiceName jmsQueueServiceName = JMSServices.getJmsQueueBaseServiceName(serverServiceName).append(queueName);
             queueService = ExternalJMSQueueService.installRuntimeQueueService(
@@ -214,7 +192,8 @@ public class JMSDestinationDefinitionInjectionSource extends ResourceDefinitionI
                             .setManagementPassword(password)
                             .build(),
                     serviceTarget,
-                    pcfName);
+                    pcfName,
+                    enabledAMQ1Prefix);
         } else {
            queueService = JMSQueueService.installService(queueName, serviceTarget, serverServiceName, selector, durable);
         }
@@ -257,6 +236,8 @@ public class JMSDestinationDefinitionInjectionSource extends ResourceDefinitionI
 
         Service<Topic> topicService;
         if(external) {
+            // check @JMSDestinationDefinitions boolean property named enable-amq1-prefix for runtime topic
+            final boolean enabledAMQ1Prefix = properties.containsKey(External.ENABLE_AMQ1_PREFIX.getName()) ? Boolean.valueOf(properties.get(External.ENABLE_AMQ1_PREFIX.getName())) : External.ENABLE_AMQ1_PREFIX.getDefaultValue().asBoolean();
             ServiceName pcfName = JMSServices.getPooledConnectionFactoryBaseServiceName(serverServiceName).append(resourceAdapter);
             final ServiceName jmsTopicServiceName = JMSServices.getJmsTopicBaseServiceName(serverServiceName).append(topicName);
             topicService = ExternalJMSTopicService.installRuntimeTopicService(
@@ -269,7 +250,8 @@ public class JMSDestinationDefinitionInjectionSource extends ResourceDefinitionI
                             .setDestinationServiceName(jmsTopicServiceName)
                             .build(),
                     serviceTarget,
-                    pcfName);
+                    pcfName,
+                    enabledAMQ1Prefix);
         } else {
             topicService = JMSTopicService.installService(topicName, serverServiceName, serviceTarget);
         }
